@@ -32,6 +32,7 @@ use Imager::Graph::Line;
 # reshape
 
 my @funcs = qw/
+  double_xs
   abs
   acos
   acosh
@@ -541,7 +542,7 @@ sub function {
 
 =head1 NAME
 
-Rstats::Class - Rstats class interface
+Rstats::Class - Rstats Object-Oriented interface
 
 =head1 SYNOPSYS
   
